@@ -1,7 +1,7 @@
 #! /usr/bin/perl
 
 # ex:ts=8 sw=4:
-# $OpenBSD: Quirks.pm,v 1.407 2016/07/11 10:16:48 sthen Exp $
+# $OpenBSD: Quirks.pm,v 1.471 2017/03/27 08:16:47 fcambus Exp $
 #
 # Copyright (c) 2009 Marc Espie <espie@openbsd.org>
 #
@@ -90,8 +90,6 @@ my $base_exceptions = {
 # 4.9
 	'video' => "/usr/X11R6/bin/video",
 	'nsd' => "/usr/sbin/nsd",
-# 5.2
-	'sqlite3' => '/usr/bin/sqlite3',
 # 5.6
 	'unbound' => '/usr/sbin/unbound',
 # 5.7
@@ -303,7 +301,6 @@ my $stem_extensions = {
 	'p5-Email-MIME-Modifier' => 'p5-Email-MIME',
 	'libmpcdec' => 'musepack',
 	'mppenc' => 'musepack',
-	'xxxterm' => 'xombrero',
 	'pecl-zip' => 'php-zip',
 	'XML-Sablotron' => 'p5-XML-Sablotron',
 # 5.3
@@ -404,6 +401,16 @@ my $stem_extensions = {
 	'openmotif' => 'motif',
 	'go-websocket' => 'go-net',
 	'letsencrypt' => 'certbot',
+# 6.1
+	'zarafa-webaccess' => 'zarafa-mapi',
+	'railo' => 'lucee',
+	'radare-bindings2' => 'radare2-bindings',
+	'py-httpie' => 'httpie',
+	'py-ripe.atlas.tools' => 'ripe.atlas.tools',
+	'u-boot' => 'u-boot-arm',
+	'ja-w3m' => 'w3m',
+	'markdown' => 'py-markdown',
+	'netperf-wrapper' => 'flent',
 };
 
 my $obsolete_reason = {
@@ -806,6 +813,49 @@ my $obsolete_reason = {
 	'yt' => 0,
 	'gmime-sharp' => 6,
 	'py-subvertpy' => 5,
+	'clamz' => 3,
+	'p5-Net-Abuse-Utils-Spamhaus' => 6,
+	'mlite' => 3,
+	'hgd' => 3,
+	'gfortran' => 5,
+	'cherokee' => 3,
+	'cherokee-geoip' => 3,
+	'cherokee-ldap' => 3,
+	'cherokee-mysql' => 3,
+	'cherokee-streaming' => 3,
+	'gecko-mediaplayer' => 3,
+	'io' => 5,
+	'dbic++' => 5,
+	'hs-postgresql-simple' => 5,
+	'hs-uuid' => 5,
+	"ocaml-mlgmp" => 3,
+	"ocaml-batteries" => 5,
+	"ocaml-bitstring" => 5,
+	"ocaml-calendar" => 5,
+	"ocaml-curses" => 5,
+	"ocaml-net" => 5,
+	"ocaml-camlimages" => 5,
+	"ocaml-cryptokit" => 5,
+	"ocaml-csv" => 5,
+	"ocaml-rss" => 5,
+	"ocaml-xml-light" => 5,
+	"ocaml-xmlm" => 5,
+	"ocaml-postgresql" => 5,
+	"ocaml-sqlite3" => 5,
+	"utop" => 7,
+	"ocaml-lambda-term" => 5,
+	"ocaml-lwt" => 5,
+	"ocaml-react" => 5,
+	"ocaml-text" => 5,
+	"ocaml-ssl" => 5,
+	"ocaml-ppx-tools" => 5,
+	"ocaml-zed" => 5,
+	"ocaml-camomile" => 5,
+	"elinks" => 2,
+	"wyrd" => 3,
+	"sudoku-solver" => 3,
+	"clearsilver" => 3,
+	"poppler-qt" => 3,
 
 # KDE3 removals
 	'amarok' => 2,
@@ -826,6 +876,82 @@ my $obsolete_reason = {
 	'taskjuggler' => 6,
 	'icinga2-migration' => 3,
 	'poppassd' => 0,
+	'wmthemeinstall' => 0,
+	'gkrellmms' => 5,
+	'py-xmms' => 5,
+	'xmms' => 5,
+	'xmms-faad' => 5,
+	'xmms-flac' => 5,
+	'xmms-fmradio' => 5,
+	'xmms-kj' => 5,
+	'xmms-mad' => 5,
+	'xmms-mikmod', => 5,
+	'xmms-mp3' => 5,
+	'xmms-shn' => 5,
+	'xmms-sid' => 5,
+	'xmms-speex' => 5,
+	'xmms-tremor' => 5,
+	'xmms-vorbis' => 5,
+	'xmms-wavpack' => 5,
+	'xmms-xf86audio' => 5,
+	'xmmsctrl' => 5,
+	'glib' => 5,
+	'gtk+' => 5,
+	'gnome-user-share' => 8,
+	'letskencrypt' => 4,
+	'emiclock' => 0,
+	'rygel' => 8,
+	'vino' => 8,
+	'ttcp' => 0,
+	'aget' => 3,
+	'xfprint' => 3,
+	'notification-daemon-xfce' => 3,
+	'xfce4-wmdock' => 3,
+	'xfce4-modemlights' => 3,
+	'xfce4-quicklauncher' => 3,
+	'libxfcegui4' => 5,
+	'libsexy' => 5,
+	'twitux' => 3,
+	'gnash' => 2,
+	'eclipse-sdk' => 2,
+	'swt' => 2,
+	'swt-gnome' => 2,
+	'eclipse-plugin-emf-sdk' => 2,
+	'eclipse-plugin-epic' => 2,
+	'eclipse-plugin-findbugs' => 2,
+	'eclipse-plugin-gef-sdk' => 2,
+	'eclipse-plugin-ivyde' => 2,
+	'py-dev' => 2,
+	'eclipse-plugin-rdt' => 2,
+	'eclipse-plugin-struts-console' => 2,
+	'eclipse-plugin-subclipse' => 2,
+	'eclipse-plugin-uml2-sdk' => 2,
+	'eclipse-plugin-wtp-sdk' => 2,
+	'lsof' => 0,
+	'l0phtcrack' => 0,
+	'bunny' => 3,
+	'jakarta-servletapi' => 5,
+	'ldistfp' => 0,
+	'rednotebook' => 5,
+	'py-webkitgtk' => 2,
+	'xombrero' => 3,
+	'claws-mail-htmlviewer' => 2,
+	'postgresql-jdbc' => 6,
+	'postgresql-jdbc-docs' => 6,
+	'vimb' => 2,
+	'plor' => 3,
+	'coherence' => 3,
+	'hugs98' => 3,
+	'hmake' => 3,
+	'nhc98' => 3,
+	'logsurfer' => 3,
+	'scsh' => 3,
+	'bladeenc' => 3,
+	'pilot_makedoc' => 6,
+	'clog' => 4,
+	'pigment' => 3,
+	'py-pigment' => 3,
+	'gogo' => 3,
 };
 
 # reasons for obsolete packages
@@ -838,6 +964,7 @@ my @msg = (
 	"outdated and/or no longer required by other ports", #5
 	"no longer useful", #6
 	"removed in favor of using languages package manager", #7
+	"requires systemd", #8
 );
 
 # ->is_base_system($handle, $state):
@@ -882,6 +1009,7 @@ sub filter_obsolete
 	for my $pkgname (@in) {
 		my $stem = OpenBSD::PackageName::splitstem($pkgname);
 		my $reason = $obsolete_reason->{$stem};
+		$reason = 3 if (!defined $reason && $pkgname =~ m/^drupal(-6|6-)/);
 		if (defined $reason) {
 			$state->say("Obsolete package: #1 (#2)", $pkgname, 
 			    $msg[$reason]);
